Threads
=======

.. autoclass:: pysimpleapp.threads.simple_threads.SimpleThread
    :members:

    .. automethod:: __init__

Single Run Thread
-----------------

.. autoclass:: pysimpleapp.threads.simple_threads.SingleRunThread
    :members:

Multi Run Thread
----------------

.. autoclass:: pysimpleapp.threads.simple_threads.MultiRunThread
    :members:

Repeating Thread
----------------

.. autoclass:: pysimpleapp.threads.simple_threads.RepeatingThread
    :members:

Precise Repeating Thread
------------------------

.. autoclass:: pysimpleapp.threads.simple_threads.PreciseRepeatingThread
    :members:
